# -*- coding: utf-8 -*-
"""Simple template file handling.
"""
#
# Copyright (C) 2011 Anders Engström <ankan@ankan.eu>
#
# This file is part of pstorytime.
#
# pstorytime is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pstorytime is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pstorytime.  If not, see <http://www.gnu.org/licenses/>.

from os.path import isfile

def generate(dest,template,replace):
  """Generate destination file from template.

  Arguments:
    dest        The file to generate.
    template    The template to generate from.
    replace     A dictionary of replacements to make.
  """
  try:
    if isfile(template):
      with open(template,'r') as f:
        template = f.read()

      try:
        with open(dest,'r') as f:
          old = f.read()
      except IOError:
        old = ""

      new = template.format(**replace)

      if old != new:
        with open(dest,'w') as f:
          f.write(new)
    else:
      print("Could not find template file. ({0})".format(template))
      exit(1)
  except IOError:
    print("Failed to generate file. ({0})".format(dest))
    exit(1)
  except ValueError as e:
    print("Failed to generate file, invalid replacements. ({0})".format(dest))
    exit(1)
